Struct XdgDialogV1
pub struct XdgDialogV1 { /* private fields */ }wayland and Linux only.Expand description
dialog object
A xdg_dialog_v1 object is an ancillary object tied to a xdg_toplevel. Its purpose is hinting the compositor that the toplevel is a “dialog” (e.g. a temporary window) relative to another toplevel (see xdg_toplevel.set_parent). If the xdg_toplevel is destroyed, the xdg_dialog_v1 becomes inert.
Through this object, the client may provide additional hints about the purpose of the secondary toplevel. This interface has no effect on toplevels that are not attached to a parent toplevel.
This interface has no events.
Implementations
impl XdgDialogV1
impl XdgDialogV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the dialog object
Destroys the xdg_dialog_v1 object. If this object is destroyed before the related xdg_toplevel, the compositor should unapply its effects.
pub fn set_modal(&self)
pub fn set_modal(&self)
mark dialog as modal
Hints that the dialog has “modal” behavior. Modal dialogs typically require to be fully addressed by the user (i.e. closed) before resuming interaction with the parent toplevel, and may require a distinct presentation.
Clients must implement the logic to filter events in the parent toplevel on their own.
Compositors may choose any policy in event delivery to the parent toplevel, from delivering all events unfiltered to using them for internal consumption.
pub fn unset_modal(&self)
pub fn unset_modal(&self)
mark dialog as not modal
Drops the hint that this dialog has “modal” behavior. See xdg_dialog_v1.set_modal for more details.